.. _lionagi-docs-index:

====================================================
LionAGI — Documentation Home Page
====================================================

Welcome to LionAGI's documentation! This site covers how to use LionAGI's
features, including:

- **Branch**: the main conversation manager,
- **Adapters**: converting data to/from external formats,
- **Operations**: powerful LLM flows (operate, instruct, parse, etc.),
- **Action system**: function-calling, advanced multi-step flows, and more.

If you're new, start with the **Tutorials**. If you're looking for deeper 
API references, check out the **Modules** sections.

Contents
========

.. toctree::
   :maxdepth: 2
   :caption: Table of Contents:

   tutorials/index
   modules/index

Indices and tables
==================

.. toctree::
   :maxdepth: 1
   :caption: Indices & Tables

   genindex
   modindex
   search
